<?php
/**
 * ownCloud Admin_Audit
 *
 * @author Joas Schilling <nickvergessen@owncloud.com>
 * @copyright (C) 2016 ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\Admin_Audit\Handlers;

use OCP\IUser;

class Session extends Base {
	/**
	 * Log login attempt
	 * @param string[] $params
	 */
	static public function pre_login($params) {
		if (isset($params['login'])) {
			$login = $params['login'];
		} elseif (isset($params['uid'])) {
			$login = $params['uid'];
		} else {
			return;
		}
		self::getLogger()->log('User {user} attempted to log into ownCloud from IP address: {ip}', [
			'user' => $login
		]);
	}

	/**
	 * Log successful login
	 * @param string[] $params
	 */
	static public function post_login($params) {
		if (isset($params['login'])) {
			$login = $params['login'];
		} elseif (isset($params['uid'])) {
			$login = $params['uid'];
		} else {
			return;
		}
		self::getLogger()->log('User {user} logged into ownCloud from IP address: {ip}', [
			'user' => $login
		]);
	}

	/**
	 * Log logout
	 */
	static public function logout() {
		$logger = self::getLogger();
		$user = $logger->getSessionUser();

		if ($user instanceof IUser) {
			$logger->log('User {user} logged out of ownCloud', [
				'user' => $user->getUID()
			]);
		}
	}
}
